==> deepin-home_1.6.0.tar.xz: BUILD/translations/deepin-home/tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Geri Bildirimlerim</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 görüntüleme</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Resmi yanıt</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Newest</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>İletişim</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Önerilerinizi gönderin</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Kaynaklar</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Join US</source>
        <translation>Bize katılın</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>Messages</source>
        <translation>İletiler</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more items</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Anasayfa</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Henüz ileti yok</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 ileti</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Tümünü okundu olarak işaretle</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Daha fazla göster</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Ağ hatası, lütfen daha sonra tekrar deneyin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Anasayfa</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fill In</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Bekleyen</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Onaylanan</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Yanıtlanan</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Çözülen</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Değerlendirmede</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Kabul Edilen</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Tamamlanan</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Yeniden Üretim</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Geri Bildirim Gönder</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Hata Raporu</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content：</source>
        <translation>İçerik:</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-posta:</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Sistem Sürümü:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Aygıt Bilgisi:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Ekran görüntüleri：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Hatalı e-posta adresi girildi.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Aygıt Bilgisi</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Lütfen e-postanızı giriniz</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Tek bir geri bildirimde birden fazla konuyu doldurmayın</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Urged</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-home_1.6.3.tar.xz: BUILD/translations/deepin-home/tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Lütfen Deepin ID&apos;nizle giriş yapın.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Sonraki işlemlere devam etmek için oturum açmanız gerekir.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Çok fazla istekte bulunuyorsunuz, lütfen daha sonra tekrar deneyin.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Sonraki işlemlere devam etmek için giriş yapmanız gerekir.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Ağ hatası, lütfen daha sonra deneyin.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Günlüğe Kaydedilmemiş</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Favorilerim</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Geri Bildirimlerim</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Giriş</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 görüntüleme</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorilerden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorilere ekle</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>İsteği iptal et</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>İstek</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Gelen</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Resmi yanıt</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Hepsi</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Sırala:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>En Yeni</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favori</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>İstek</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>İletişim</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Burada tartışın ve paylaşın</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Hata raporu</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Bulduğun sorunları rapor et</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Önerilerinizi gönderin</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Kaynaklar</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Anket</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Bize katılın</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Dahili Test</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation>Topluluk Haberleri</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Daha fazla ürün yok</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>İletiler</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Anketler</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Sistem başlangıcında başlat</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Anasayfa</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Forumlara hızlı giriş yapın, öneri gönderin ve hataları bildirin.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Henüz ileti yok</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 ileti</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Tümünü okundu olarak işaretle</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Daha fazla göster</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Ağ hatası, lütfen daha sonra tekrar deneyin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Anasayfa</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Henüz soru sorulmadı.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Bitiş zamanı: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Formu doldur</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Bekleyen</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Yeniden Üretim</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Onaylanan</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Yanıtlanan</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Çözülen</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Değerlendirmede</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Kabul Edilen</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Tamamlanan</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Sorun işlenmedi. Herkese açık listede gösterilmeyecek.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Şu anda nedeni belirlenemiyor; Sürekli izleme ve soruşturma gereklidir.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Sorun yeniden oluşturuldu ve kök neden belirlendi.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Bu sorun bir hata veya farklı bir nitelik değildir.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Sorun çözüldü ve resmi olarak yayınlanmayı bekliyor</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Gereksinim işlenmedi. Genel listede gösterilmeyecek</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Sorun kabul edildi ve dahili olarak değerlendiriliyor</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Gelecekteki bir sürüm için planlara dahil edildi</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Gereksinim kabul edilmiyor veya ele alınamıyor</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Geliştirme çalışmaları tamamlandı ve resmi olarak yayınlanmayı bekliyor</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Ekran görüntüsü eklenemiyor.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Görüntü dosyasının boyutu 1 MB&apos;tan küçük olmalıdır.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Görüntü dosyası formatı yükleme için desteklenmiyor.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Ürünün Mevcut Durumu]: 
[İstenen Ürün]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Ön koşullar]: 
[Tekrarlanabilirlik Adımları]: 
[Beklenen Sonuçlar]: 
[Gerçek Sonuçlar]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Geri Bildirim Gönder</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Öneriler</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Hata Raporu</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Başlık:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Lütfen sorununuzla ilgili kısa bir açıklama yapın</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>İçerik:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Tek bir geri bildirimde birden fazla konuyu doldurmayın</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Tek bir geri bildirimde birden fazla gereksinimi doldurmayın</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-posta:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Lütfen e-postanızı giriniz</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Sistem Sürümü:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Aygıt Bilgisi:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;home://sysinfo&apos;&gt;Cihaz bilgilerini&lt;/a&gt; karşıya yükle</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Ekran görüntüleri：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Görüntü dosyaları</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Dosyaları sürükleyip bırakın veya resim eklemek için butonlara tıklayın, en fazla üç tane</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Geri bildirim gönderiminden çıkmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Geri bildirim içeriği kaydedilmeyecektir.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Geri bildirim gönderilemiyor.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Lütfen geri bildiriminizin başlığını ve içeriğini belirtin .</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Lütfen geri bildiriminizin başlığını belirtin.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Lütfen geri bildiriminizin içeriğini belirtin.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Hatalı e-posta adresi girildi.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Aygıt Bilgisi</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Geri Bildirim Merkezi</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Geri Bildirimlerim</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Favorilerim</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>İsteklerim</translation>
    </message>
</context>
</TS>
